==> MazamaLocationUtils_0.1.6.tar.gz: MazamaLocationUtils/R/mazama_initialize.R <==

#' @title Initialize with MazamaScience standard directories
#' @description Convenience function to initialize spatial data. Wraps the 
#' following setup lines:
#' 
#' \preformatted{
#' MazamaSpatialUtils::setSpatialDataDir(spatialDataDir)
#' 
#' MazamaSpatialUtils::loadSpatialData("EEZCountries")
#' MazamaSpatialUtils::loadSpatialData("OSMTimezones")
#' MazamaSpatialUtils::loadSpatialData("NaturalEarthAdm1")
#' MazamaSpatialUtils::loadSpatialData("USCensusCounties")
#' }
#' @param spatialDataDir Directory where spatial datasets are found, 
#' Default: "~/Data/Spatial"
#' @return No return value.
#' @rdname mazama_initialize
#' @examples
#' \donttest{
#' # Set up directory for spatial data
#' spatialDataDir <- tempdir() # typically "~/Data/Spatial"
#' MazamaSpatialUtils::setSpatialDataDir(spatialDataDir)
#' 
#' # Install core spatial datasets (168 MB download)
#' MazamaSpatialUtils::installSpatialData()
#' 
#' exists("NaturalEarthAdm1")
#' mazama_initialize(spatialDataDir)
#' exists("NaturalEarthAdm1")
#' class(NaturalEarthAdm1)
#' }
#' @export 
#' @importFrom MazamaSpatialUtils setSpatialDataDir loadSpatialData
#' 
mazama_initialize <- function(
  spatialDataDir = "~/Data/Spatial"
) {
  
  # Is everything already initialized?
  result <- try({
    validateMazamaSpatialUtils() # swallow warning messages
  }, silent = TRUE)

  if ( "try-error" %in% class(result) ) {
    
    # Not initialized, so try to initialize
    result <- try({
      MazamaSpatialUtils::setSpatialDataDir(spatialDataDir)
      MazamaSpatialUtils::loadSpatialData("EEZCountries")
      MazamaSpatialUtils::loadSpatialData("OSMTimezones")
      MazamaSpatialUtils::loadSpatialData("NaturalEarthAdm1")
      MazamaSpatialUtils::loadSpatialData("USCensusCounties")
    }, silent = TRUE)
    
    if ( "try-error" %in% class(result) ) {
      # Installation failed so spit out warning messages
      validateMazamaSpatialUtils()
    }
   
  }
  
}

==> MazamaLocationUtils_0.1.13.tar.gz: MazamaLocationUtils/R/mazama_initialize.R <==
#' @rdname mazama_initialize
#' 
#' @export 
#' @importFrom MazamaSpatialUtils setSpatialDataDir loadSpatialData
#' 
#' @title Initialize with MazamaScience standard directories
#' 
#' @param spatialDataDir Directory where spatial datasets are found, 
#' Default: "~/Data/Spatial"
#' 
#' @return No return value.
#' 
#' @description Convenience function to initialize spatial data. Wraps the 
#' following setup lines:
#' 
#' \preformatted{
#' MazamaSpatialUtils::setSpatialDataDir(spatialDataDir)
#' 
#' MazamaSpatialUtils::loadSpatialData("EEZCountries")
#' MazamaSpatialUtils::loadSpatialData("OSMTimezones")
#' MazamaSpatialUtils::loadSpatialData("NaturalEarthAdm1")
#' MazamaSpatialUtils::loadSpatialData("USCensusCounties")
#' }
#' 
#' @examples
#' \donttest{
#' library(MazamaLocationUtils)
#' 
#' # Set up directory for spatial data
#' spatialDataDir <- tempdir() # typically "~/Data/Spatial"
#' MazamaSpatialUtils::setSpatialDataDir(spatialDataDir)
#' 
#' exists("NaturalEarthAdm1")
#' mazama_initialize(spatialDataDir)
#' exists("NaturalEarthAdm1")
#' class(NaturalEarthAdm1)
#' }
mazama_initialize <- function(
  spatialDataDir = "~/Data/Spatial"
) {
  
  # Is everything already initialized?
  result <- try({
    validateMazamaSpatialUtils() # swallow warning messages
  }, silent = TRUE)

  if ( "try-error" %in% class(result) ) {
    
    # Not initialized, so try to initialize
    result <- try({
      MazamaSpatialUtils::setSpatialDataDir(spatialDataDir)
      # Install if not found
      MazamaSpatialUtils::installSpatialData("EEZCountries")
      MazamaSpatialUtils::installSpatialData("OSMTimezones")
      MazamaSpatialUtils::installSpatialData("NaturalEarthAdm1")
      MazamaSpatialUtils::installSpatialData("USCensusCounties")
      # Now load
      MazamaSpatialUtils::loadSpatialData("EEZCountries")
      MazamaSpatialUtils::loadSpatialData("OSMTimezones")
      MazamaSpatialUtils::loadSpatialData("NaturalEarthAdm1")
      MazamaSpatialUtils::loadSpatialData("USCensusCounties")
    }, silent = TRUE)
    
    if ( "try-error" %in% class(result) ) {
      # Installation failed so spit out warning messages
      validateMazamaSpatialUtils()
    }
   
  }
  
}
